#[repr(u8)]pub enum NumericWidth {
I8 = 0,
I16 = 1,
I32 = 2,
I64 = 3,
U8 = 4,
U16 = 5,
U32 = 6,
U64 = 7,
F32 = 8,
F64 = 9,
}Expand description
Numeric width tag for compact typed opcodes (AddTyped, SubTyped, etc.).
Encodes the operand width so a single opcode family can handle all numeric types. The discriminant values are part of the bytecode ABI and must remain stable.
Variants
Implementations
Sourceimpl NumericWidth
impl NumericWidth
pub const ALL: [Self; 10]
pub const fn is_integer(self) -> bool
pub const fn is_float(self) -> bool
Sourcepub const fn is_unsigned(self) -> bool
pub const fn is_unsigned(self) -> bool
Whether this is an unsigned integer type.
Sourcepub fn from_int_width(w: IntWidth) -> Self
pub fn from_int_width(w: IntWidth) -> Self
Convert from IntWidth (shape-ast) to NumericWidth.
Sourcepub fn to_int_width(self) -> Option<IntWidth>
pub fn to_int_width(self) -> Option<IntWidth>
Convert to IntWidth (shape-ast). Returns None for F32/F64/I64.