Bytecode compiler - translates AST to bytecode
Modules
- string_
interpolation - Compile-time string interpolation compilation.
Structs
- Bytecode
Compiler - Compiler state
Enums
- Borrow
Mode - Borrow mode for reference parameters - Shared (&) or Exclusive (&mut). Kept for codegen even though the lexical borrow checker has been removed.
- Compile
Diagnostic Mode - Param
Pass Mode - Canonical compile-time parameter passing contract.
- Type
Diagnostic Mode
Functions
- infer_
param_ pass_ modes - Infer effective parameter pass modes (
ByValue/ByRefShared/ByRefExclusive) keyed by function name. - infer_
reference_ model - Infer effective reference parameters and mutation behavior without compiling bytecode.
Type Aliases
- Borrow
Place - A borrow place key used for encoding borrow targets in codegen.