Virtual machine executor for Shape bytecode
Re-exports
pub use task_scheduler::TaskScheduler;pub use task_scheduler::TaskStatus;
Modules
- debugger_
integration - Debugger integration for the VM
- foreign_
marshal - Shape-value <-> MessagePack marshaling for foreign function calls.
- gc_
integration - Garbage collection integration for the VM
- module_
registry - Module function registry for the VM
- native_
abi - Native C ABI linking and invocation for
extern Cforeign functions. - printing
- VM-native value formatting (ADR-006 2.7.4 — output adapter).
- state_
builtins - task_
scheduler - Task scheduler for the async host runtime.
- time_
travel - Time-travel debugging support for the Shape VM.
- typed_
object_ ops - TypedObject operations for the VM.
- utils
- v2_
handlers - v2 opcode handlers — typed struct field, typed array, and sized integer operations.
Structs
- Call
Frame - Call frame for function calls
- DebugVM
State - Debug VM state snapshot for the debugger
- Suspension
Info - Information about why execution was suspended
- VMConfig
- VM configuration
- Virtual
Machine - The Shape virtual machine
Enums
- Async
Execution Result - Result of executing an async operation
- Execution
Result - Result of VM execution.
- Permission
Error - Error returned when a program requires permissions not granted by the host.
- Wait
Type - Type of wait condition
Constants
- SNAPSHOT_
FUTURE_ ID - Reserved future ID used to signal a snapshot suspension
Functions
- reset_
transport_ provider - Restore the default shape-wire transport provider.
- set_
transport_ provider - Replace the active wire transport provider used by VM transport builtins.
Type Aliases
- JitFn
Ptr - Function pointer type for JIT-compiled functions.
ctxis a mutable pointer to VM execution context (e.g., stack base).argsis a pointer to the argument buffer. Returns a NaN-boxed result as raw u64 bits.