pub fn std_elements(view: &V2TypedArrayView) -> Option<(u64, NativeKind)>Expand description
Compute the sample standard deviation of a float v2 typed array.
pub fn std_elements(view: &V2TypedArrayView) -> Option<(u64, NativeKind)>Compute the sample standard deviation of a float v2 typed array.