Module coverage

Module coverage 

Coverage analysis for feature tests

This module analyzes which grammar rules are covered by tests and reports on coverage gaps.

Structs

CoverageReport

Functions

analyze_coverage
Analyze coverage gaps between registered tests and grammar features