pub fn all_feature_tests() -> Vec<&'static FeatureTest>Expand description
Returns all feature tests from all modules for coverage analysis
pub fn all_feature_tests() -> Vec<&'static FeatureTest>Returns all feature tests from all modules for coverage analysis