BorrowErrorKind

Enum BorrowErrorKind 

pub enum BorrowErrorKind {
Show 15 variants ConflictSharedExclusive, ConflictExclusiveExclusive, ReadWhileExclusivelyBorrowed, WriteWhileBorrowed, ReferenceEscape, ReferenceStoredInArray, ReferenceStoredInObject, ReferenceStoredInEnum, ReferenceEscapeIntoClosure, UseAfterMove, ExclusiveRefAcrossTaskBoundary, SharedRefAcrossDetachedTask, InconsistentReferenceReturn, CallSiteAliasConflict, NonSendableAcrossTaskBoundary,
}

Variants



ConflictSharedExclusive

Cannot borrow as mutable while shared borrow is active.



ConflictExclusiveExclusive

Cannot borrow as mutable while another mutable borrow is active.



ReadWhileExclusivelyBorrowed

Cannot read while exclusively borrowed.



WriteWhileBorrowed

Cannot write while any borrow is active.



ReferenceEscape

Reference escapes its scope.



ReferenceStoredInArray

Reference stored into an array.



ReferenceStoredInObject

Reference stored into an object or struct literal.



ReferenceStoredInEnum

Reference stored into an enum payload.



ReferenceEscapeIntoClosure

Reference escapes into a closure environment.



UseAfterMove

Use after move.



ExclusiveRefAcrossTaskBoundary

Cannot share exclusive reference across task boundary.



SharedRefAcrossDetachedTask

Cannot share any reference across detached task boundary.



InconsistentReferenceReturn

Reference returns must produce a reference on every path from the same borrowed origin and borrow kind.



CallSiteAliasConflict

Two arguments at a call site alias the same variable but the callee requires them to be non-aliased (one is mutated, the other is read).



NonSendableAcrossTaskBoundary

Non-sendable value (e.g., closure with mutable captures) sent across a detached task boundary.

Implementations

Source

impl BorrowErrorKind

pub fn code(&self) -> BorrowErrorCode

Map this error kind to the stable user-facing error code.