pub struct LivenessResult {
pub live_in: HashMap<BasicBlockId, HashSet<SlotId>>,
pub live_out: HashMap<BasicBlockId, HashSet<SlotId>>,
}Expand description
Result of liveness analysis for a MIR function.
Fields
live_in: HashMap<BasicBlockId, HashSet<SlotId>>Variables live at the entry of each block.
live_out: HashMap<BasicBlockId, HashSet<SlotId>>Variables live at the exit of each block.
Implementations
Sourceimpl LivenessResult
impl LivenessResult
Sourcepub fn is_live_after(
&self,
block: BasicBlockId,
stmt_idx: usize,
slot: SlotId,
mir: &MirFunction,
) -> bool
pub fn is_live_after( &self, block: BasicBlockId, stmt_idx: usize, slot: SlotId, mir: &MirFunction, ) -> bool
Check if a variable is live at a given point within a block. Walks backwards from the block exit to the statement index.
Sourcepub fn is_live_at_entry(&self, block: BasicBlockId, slot: SlotId) -> bool
pub fn is_live_at_entry(&self, block: BasicBlockId, slot: SlotId) -> bool
Check if a variable is live at the entry of a block.