ModuleSourceKindHint

Enum ModuleSourceKindHint 

pub enum ModuleSourceKindHint {
    NativeExtension,
    ShapeSource,
    EmbeddedStdlib,
    CompiledBundle,
    NotFound,
}
Classification hint for how a module path should be resolved.

Used during graph construction to decide how to handle each dependency.

Variants



NativeExtension

Module is backed by a native extension (Rust ModuleExports).



ShapeSource

Module has .shape source code available.



EmbeddedStdlib

Module is an embedded stdlib module.



CompiledBundle

Module is available only as a pre-compiled bundle.



NotFound

Module could not be found.