pub fn resolve_module_source_kind(
loader: &ModuleLoader,
module_path: &str,
) -> ModuleSourceKindHintExpand description
Classify a module path by probing the module loader’s resolvers.
pub fn resolve_module_source_kind(
loader: &ModuleLoader,
module_path: &str,
) -> ModuleSourceKindHintClassify a module path by probing the module loader’s resolvers.