Module module_resolution

Module module_resolution 

Module loading, virtual module resolution, and file-based import handling.

Methods for resolving imports via virtual modules (extension-bundled sources), file-based module loaders, and the module loader configuration API.

Functions

build_graph_and_stdlib_names
Build a module graph and compute stdlib names from the prelude modules.