pub fn handle_negotiation(
request: &BlobNegotiationRequest,
cache: &RemoteBlobCache,
) -> BlobNegotiationResponseExpand description
Handle a blob negotiation request on the server side.
Returns the subset of offered hashes that are present in the cache.