pub fn program_hash(program: &BytecodeProgram) -> [u8; 32]Expand description
Compute a SHA-256 hash of a BytecodeProgram for caching.
Remote VMs can cache programs by this hash, avoiding re-transfer of the same program on repeated calls.
pub fn program_hash(program: &BytecodeProgram) -> [u8; 32]Compute a SHA-256 hash of a BytecodeProgram for caching.
Remote VMs can cache programs by this hash, avoiding re-transfer of the same program on repeated calls.