pub struct BlobNegotiationResponse {
pub known_hashes: Vec<FunctionHash>,
}Expand description
Response indicating which offered blobs are already cached on the remote side.
Fields
known_hashes: Vec<FunctionHash>Subset of offered hashes that the remote already has in its blob cache.