pub fn compile_directory(dir: &Path) -> Result<BytecodeProgram>Expand description
Compile all Shape files in a directory (recursively) into a single BytecodeProgram.
Each file is compiled independently, then merged via merge_append.
pub fn compile_directory(dir: &Path) -> Result<BytecodeProgram>Compile all Shape files in a directory (recursively) into a single BytecodeProgram.
Each file is compiled independently, then merged via merge_append.