Bytecode verifier for trusted opcodes.
Validates that trusted opcode invariants hold:
- Every trusted opcode appears inside a function with a
FrameDescriptor - The FrameDescriptor has no
SlotKind::Unknownentries for the relevant operands
Enums
- Verify
Error - Errors produced by the bytecode verifier.
Functions
- verify_
trusted_ opcodes - Verify that all trusted opcodes in a program have valid FrameDescriptors.