verify_trusted_opcodes

Function verify_trusted_opcodes 

pub fn verify_trusted_opcodes(
    program: &BytecodeProgram,
) -> Result<(), Vec<VerifyError>>
Verify that all trusted opcodes in a program have valid FrameDescriptors.

Returns Ok(()) if all trusted opcodes pass verification, or a list of all violations found.