Module string_interpolation

Module string_interpolation 

Compile-time string interpolation compilation.

Interpolation syntax parsing itself lives in shape-ast so compiler, type inference, and LSP all use the same parser.

Functions

has_interpolation
Check whether a string contains at least one interpolation segment.
has_interpolation_with_mode
Check whether a string contains at least one interpolation segment for the mode.