Compile-time string interpolation compilation.
Interpolation syntax parsing itself lives in shape-ast so compiler,
type inference, and LSP all use the same parser.
Functions
- has_
interpolation - Check whether a string contains at least one interpolation segment.
- has_
interpolation_ with_ mode - Check whether a string contains at least one interpolation segment for the mode.