Module executor

Module executor 

Virtual machine executor for Shape bytecode

Re-exports

pub use task_scheduler::TaskScheduler;
pub use task_scheduler::TaskStatus;

Modules

debugger_integration
Debugger integration for the VM
foreign_marshal
ValueWord <-> MessagePack marshaling for foreign function calls.
gc_integration
Garbage collection integration for the VM
module_registry
Module function registry for the VM
native_abi
Native C ABI linking and invocation for extern C foreign functions.
printing
VM-native value formatting
state_builtins
task_scheduler
Task scheduler for the async host runtime.
time_travel
Time-travel debugging support for the Shape VM.
typed_object_ops
TypedObject operations for the VM
utils

Structs

CallFrame
Call frame for function calls
DebugVMState
Debug VM state snapshot for the debugger
SuspensionInfo
Information about why execution was suspended
VMConfig
VM configuration
VirtualMachine
The Shape virtual machine

Enums

AsyncExecutionResult
Result of executing an async operation
ExecutionResult
Result of VM execution
PermissionError
Error returned when a program requires permissions not granted by the host.
WaitType
Type of wait condition

Constants

SNAPSHOT_FUTURE_ID
Reserved future ID used to signal a snapshot suspension

Functions

reset_transport_provider
Restore the default shape-wire transport provider.
set_transport_provider
Replace the active wire transport provider used by VM transport builtins.