Native C ABI linking and invocation for extern C foreign functions.
Structs
- Native
Linked Function - Linked native function handle used by VM foreign-call dispatch.
Native C ABI linking and invocation for extern C foreign functions.