pub enum BorrowErrorKind {
ConflictSharedExclusive,
ConflictExclusiveExclusive,
ReadWhileExclusivelyBorrowed,
WriteWhileBorrowed,
ReferenceEscape,
UseAfterMove,
ExclusiveRefAcrossTaskBoundary,
}Variants
Cannot borrow as mutable while shared borrow is active.
ConflictExclusiveExclusive
Cannot borrow as mutable while another mutable borrow is active.
ReadWhileExclusivelyBorrowed
Cannot read while exclusively borrowed.
WriteWhileBorrowed
Cannot write while any borrow is active.
ReferenceEscape
Reference escapes its scope.
UseAfterMove
Use after move.
ExclusiveRefAcrossTaskBoundary
Cannot share exclusive reference across task boundary.