pub struct MirBuilder { /* private fields */ }Expand description
Builder for constructing a MIR function from AST.
Implementations
Sourceimpl MirBuilder
impl MirBuilder
pub fn new(name: String, span: Span) -> Self
Sourcepub fn alloc_local(&mut self, name: String, type_info: LocalTypeInfo) -> SlotId
pub fn alloc_local(&mut self, name: String, type_info: LocalTypeInfo) -> SlotId
Allocate a new local variable slot.
Sourcepub fn add_param(&mut self, name: String, type_info: LocalTypeInfo) -> SlotId
pub fn add_param(&mut self, name: String, type_info: LocalTypeInfo) -> SlotId
Register a parameter slot.
Sourcepub fn next_point(&mut self) -> Point
pub fn next_point(&mut self) -> Point
Allocate a new program point.
Sourcepub fn new_block(&mut self) -> BasicBlockId
pub fn new_block(&mut self) -> BasicBlockId
Create a new basic block and return its ID.
Sourcepub fn push_stmt(&mut self, kind: StatementKind, span: Span)
pub fn push_stmt(&mut self, kind: StatementKind, span: Span)
Push a statement into the current block.
Sourcepub fn finish_block(&mut self, terminator_kind: TerminatorKind, span: Span)
pub fn finish_block(&mut self, terminator_kind: TerminatorKind, span: Span)
Finish the current block with a terminator and switch to a new block.
Sourcepub fn start_block(&mut self, id: BasicBlockId)
pub fn start_block(&mut self, id: BasicBlockId)
Start building a new block (after finishing the previous one).
Sourcepub fn build(self) -> MirFunction
pub fn build(self) -> MirFunction
Finalize and produce the MIR function.