pub struct StoragePlan {
pub slot_classes: HashMap<SlotId, BindingStorageClass>,
pub slot_semantics: HashMap<SlotId, BindingSemantics>,
}Expand description
The computed storage plan for a single function.
Fields
slot_classes: HashMap<SlotId, BindingStorageClass>Maps each local slot to its decided storage class.
slot_semantics: HashMap<SlotId, BindingSemantics>Maps each local slot to its enriched binding semantics.