Module loading, virtual module resolution, and file-based import handling.
Methods for resolving imports via virtual modules (extension-bundled sources), file-based module loaders, and the module loader configuration API.
Functions
- build_
graph_ and_ stdlib_ names - Build a module graph and compute stdlib names from the prelude modules.