pub fn build_call_request(
program: &BytecodeProgram,
function_name: &str,
arguments: Vec<SerializableVMValue>,
) -> RemoteCallRequestExpand description
Build a RemoteCallRequest for a named function.
Convenience function that handles program hashing and type schema extraction. When the program has content-addressed blobs, automatically computes the minimal transitive closure and attaches it to the request.