handle_negotiation

Function handle_negotiation 

pub fn handle_negotiation(
    request: &BlobNegotiationRequest,
    cache: &RemoteBlobCache,
) -> BlobNegotiationResponse
Handle a blob negotiation request on the server side.

Returns the subset of offered hashes that are present in the cache.