pub fn program_from_blobs_by_hash(
blobs: Vec<(FunctionHash, FunctionBlob)>,
entry_hash: FunctionHash,
source: &BytecodeProgram,
) -> Option<Program>Expand description
Build a minimal Program from function blobs and an explicit entry hash.
Used on the callee side to reconstruct a Program from blobs received in
a RemoteCallRequest.