pub trait CompilationBackend: Send + 'static {
// Required method
fn compile(
&mut self,
request: &CompilationRequest,
program: &BytecodeProgram,
) -> CompilationResult;
}Expand description
Backend trait for pluggable JIT compilation.
Implementations receive compilation requests and produce results. The
TierManager owns the worker thread that drives the backend.
Required Methods
Sourcefn compile(
&mut self,
request: &CompilationRequest,
program: &BytecodeProgram,
) -> CompilationResult
fn compile( &mut self, request: &CompilationRequest, program: &BytecodeProgram, ) -> CompilationResult
Compile a function or loop according to the request.